@@ -8,6 +8,7 @@ import pyarrow as pa
 from pytest import raises
 from triad.utils.pandas_like import PD_UTILS
 from triad.utils.pyarrow import expression_to_schema
+import pickle
 
 
 def test_to_schema():
@@ -105,6 +106,15 @@ def test_nested():
     assert [[[1, 2]]] == a
 
 
+def test_binary():
+    b = pickle.dumps("xyz")
+    data = [[b, b"xy"]]
+    s = expression_to_schema("a:bytes,b:bytes")
+    df = DF(data, "a:bytes,b:bytes")
+    a = df.as_array(type_safe=True)
+    assert [[b, b"xy"]] == a
+
+
 def test_nan_none():
     df = DF([[None, None]], "b:str,c:double", True)
     assert df.native.iloc[0, 0] is None
